==> miniprogram-build-3.1.0.tgz: package/src/compiler/compile-wxss.js <==
///@ts-check
'use strict';
var gulp = require('gulp');
var rename = require('gulp-rename');
var sass = require('gulp-sass');
var sourcemaps = require('gulp-sourcemaps');
var debug = require('gulp-debug');
var cssnano = require('cssnano');
var postcss = require('gulp-postcss');
var inline = require('../lib/inline');
var empty = require('../lib/empty');
var size = require('gulp-size');
var wxssImporter = require('../lib/wxss-importer');
var replace = require('../lib/multi-replace');

var TITLE = 'wxss:';
/**
 * 编译scss
 * @param {object} config
 * @param {string|string[]} scssFile  编译源 
 * @returns {NodeJS.ReadWriteStream}
 */
function compileScss(config, scssFile) {
    return gulp.src(scssFile, { base: config.src })
        .pipe(config.release ? empty() : sourcemaps.init())
        .pipe(debug({ title: TITLE }))
        .pipe(sass({
            ///@ts-ignore
            importer: wxssImporter,
            errLogToConsole: true,
            outputStyle: config.release ? 'compressed' : 'expanded',
            includePaths: ['node_modules'],
            sourceMapEmbed: !config.release,
        }))
        .on('error', function (err) {
            sass.logError.call(this, err);
            this.emit('end');
        })
        .pipe(replace(/@import url\(__(.*)__\)\;/g, ($1, $2) => {
            return '@import "' + $2 + '";';
        }))
        .pipe(inline())
        .pipe(config.release ? postcss([cssnano()]) : empty())
        .pipe(config.release ? empty() : sourcemaps.write())
        .pipe(rename({ 'extname': '.wxss' }))
        .pipe(size({ title: TITLE, showFiles: true }))
        .pipe(gulp.dest(config.dist))
}

module.exports = compileScss

==> miniprogram-build-3.2.1.tgz: package/src/compiler/compile-wxss.js <==
///@ts-check
'use strict';
var gulp = require('gulp');
var rename = require('gulp-rename');
var sass = require('gulp-sass');
var sourcemaps = require('gulp-sourcemaps');
var debug = require('gulp-debug');
var cssnano = require('cssnano');
var postcss = require('gulp-postcss');
var size = require('gulp-size');
var inline = require('../lib/inline');
var empty = require('../lib/empty');
var wxssImporter = require('../lib/wxss-importer');
var replace = require('../lib/multi-replace');
var err = require('../log/error');

var TITLE = 'wxss:';
/**
 * 编译scss
 * @param {object} config
 * @param {string|string[]} scssFile  编译源 
 * @returns {NodeJS.ReadWriteStream}
 */
function compileScss(config, scssFile) {
    return gulp.src(scssFile, { base: config.src })
        .pipe(config.release ? empty() : sourcemaps.init())
        .pipe(debug({ title: TITLE }))
        .pipe(sass({
            ///@ts-ignore
            importer: wxssImporter,
            errLogToConsole: true,
            outputStyle: config.release ? 'compressed' : 'expanded',
            includePaths: ['node_modules'],
            sourceMapEmbed: !config.release,
        }))
        .on('error', function (err) {
            sass.logError.call(this, err);
            this.emit('end');
        })
        .pipe(replace(/@import url\(["']?([\w\/\.\-\_]*)["']?\)/g, ($1, $2) => {
            return '@import "' + $2 + '"';
        }))
        .pipe(inline())
        .pipe(config.release ? postcss([cssnano()]) : empty())
        .pipe(config.release ? empty() : sourcemaps.write())
        .pipe(rename({ 'extname': '.wxss' }))
        .pipe(size({ title: TITLE, showFiles: true }))
        .pipe(gulp.dest(config.dist))
}

module.exports = compileScss
